@@ -1,4 +1,5 @@
 from datetime import datetime
+from typing import Union
 
 
 EPOCH = datetime.utcfromtimestamp(0)
@@ -10,3 +11,10 @@ def date2microseconds(date: datetime) -> int:
 
 def microseconds2date(microseconds: float) -> datetime:
     return datetime.utcfromtimestamp(microseconds / 1000000)
+
+
+def try_parse_float(x: Union[str, float, int]) -> Union[float, str]:
+    try:
+        return float(x)
+    except ValueError:
+        return x
